pub struct ResolvedEntry {
pub risk_multiplier: f64,
pub symbol: String,
pub side: Side,
pub order_type: OrderType,
pub price: Option<f64>,
pub stoploss: Option<f64>,
pub targets: Vec<TargetSpec>,
pub rules: Vec<RuleConfig>,
pub group: Option<GroupId>,
pub trade_id: Option<TradeId>,
pub target_resolution: TargetResolution,
pub level_resolution: EntryLevelResolution,
}Expand description
A resolved entry that retains risk intent without assigning concrete lots.
Fields
risk_multiplier: f64symbol: Stringside: Sideorder_type: OrderTypeprice: Option<f64>stoploss: Option<f64>targets: Vec<TargetSpec>rules: Vec<RuleConfig>group: Option<GroupId>trade_id: Option<TradeId>target_resolution: TargetResolutionlevel_resolution: EntryLevelResolutionImplementations
Sourceimpl ResolvedEntry
impl ResolvedEntry
Sourcepub fn into_action(self, lot_size: f64) -> Action
pub fn into_action(self, lot_size: f64) -> Action
Finalize the resolved entry with a concrete lot size.