pub struct TargetResolution {
pub source: TargetResolutionSource,
pub selection: TargetSelection,
pub selected_indices: Vec<usize>,
pub generated: Vec<GeneratedTargetResolution>,
pub weights: Vec<f64>,
pub remainder: f64,
}Expand description
Metadata describing how signal targets were selected and weighted.
Fields
source: TargetResolutionSourceselection: TargetSelectionselected_indices: Vec<usize>Resolved 1-based signal indices in output order.
generated: Vec<GeneratedTargetResolution>weights: Vec<f64>Close weights corresponding one-to-one with resolved targets.
remainder: f64Fraction of the original position not assigned to a target.