Receiver

Struct Receiver 

pub struct Receiver { /* private fields */ }
A receiver that can receive files

Implementations

Source

impl Receiver

pub async fn connect( this_endpoint: Endpoint, node_addr: NodeAddr, args: ReceiverArgs, ) -> Result<Self, ReceiveError>

pub async fn close(&mut self)

Close the connection

pub async fn wait_for_close(&mut self)

Wait for the other peer to close the connection

pub async fn connection_type(&self) -> Option<ConnectionType>

Get the type of the connection

pub async fn receive_files( &mut self, initial_progress_callback: impl FnMut(&[(String, u64, u64)]), accept_files_callback: impl FnMut(&[FilesAvailable]) -> Option<PathBuf>, read_callback: &mut impl FnMut(u64), should_continue: &mut impl FnMut() -> bool, ) -> Result<bool, ReceiveError>

Receive files

Arguments
  • initial_progress_callback - Callback with the initial progress of each file to send (name, current, total)
  • accept_files_callback - Callback to accept or reject the files (Some(path) to accept, None to reject)
  • read_callback - Callback every time data is written to disk
  • should_continue - Callback to check if the transfer should continue
Returns
  • Ok(true) if the transfer was finished successfully
  • Ok(false) if the transfer was stopped