pub enum LotCapStatus {
NotCapped,
CappedAtMaximum,
}Expand description
Indicates whether the symbol maximum reduced the computed lot steps.
Variants
NotCapped
The computed lot steps did not exceed the symbol maximum.
CappedAtMaximum
The computed lot steps were reduced to the symbol maximum.