pub fn validate_entry_class(value: &str) -> Result<(), RawSignalValidationError>Expand description
Validate one optional semantic entry class without normalizing it.
pub fn validate_entry_class(value: &str) -> Result<(), RawSignalValidationError>Validate one optional semantic entry class without normalizing it.